==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/socksstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>SocksOptionsClass</name>
    <message>
        <source>Incoming Direct Connections</source>
        <translation>Входящее прямое подключение</translation>
    </message>
    <message>
        <source>Disable direct connections</source>
        <translation>Запретить прямые подключения</translation>
    </message>
    <message>
        <source>Port Forwarding</source>
        <translation>Перенаправление портов</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Stream Proxy</source>
        <translation>Прокси потока</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Вверх</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Connection Proxy</source>
        <translation>Прокси подключения</translation>
    </message>
    <message>
        <source>Use account connection proxy settings</source>
        <translation>Использовать настройки прокси из аккаунта</translation>
    </message>
    <message>
        <source>Listening port:</source>
        <translation>Прослушиваемый порт:</translation>
    </message>
    <message>
        <source>Use proxy on account server</source>
        <translation>Использовать прокси на сервере аккаунта</translation>
    </message>
</context>
<context>
    <name>SocksStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Поток удалён</translation>
    </message>
    <message>
        <source>Unsupported stream mode</source>
        <translation>Не поддерживаемый режим потока</translation>
    </message>
    <message>
        <source>Remote client cant connect to given hosts</source>
        <translation>Удалённый клиент не смог подключиться к полученным хостам</translation>
    </message>
    <message>
        <source>Failed to activate stream</source>
        <translation>Не удалось активировать поток</translation>
    </message>
    <message>
        <source>Remote client is timed out to connect</source>
        <translation>Удалённый клиент не ответил на запрос подключения</translation>
    </message>
    <message>
        <source>Failed to create hosts</source>
        <translation>Не удалось создать хост</translation>
    </message>
    <message>
        <source>Direct connection not established</source>
        <translation>Прямое подключение не установлено</translation>
    </message>
    <message>
        <source>Invalid host</source>
        <translation>Неверный хост</translation>
    </message>
    <message>
        <source>Cant connect to given hosts</source>
        <translation>Не удалось подключиться к полученным хостам</translation>
    </message>
    <message>
        <source>Failed to connect to host</source>
        <translation>Не удалось подключиться к хосту</translation>
    </message>
</context>
<context>
    <name>SocksStreams</name>
    <message>
        <source>SOCKS5 Data Stream</source>
        <translation>SOCKS5 поток данных</translation>
    </message>
    <message>
        <source>Allows to initiate SOCKS5 stream of data between two XMPP entities</source>
        <translation>Позволяет инициировать SOCKS5 поток данных между двумя XMPP сущностями</translation>
    </message>
    <message>
        <source>Supports the initiating of the SOCKS5 stream of data between two XMPP entities</source>
        <translation>Поддерживает инициализацию SOCKS5 потока данных между двумя XMPP сущностями</translation>
    </message>
    <message>
        <source>Data is transferred out-band over TCP or UDP connection</source>
        <translation>Данные передаются по отдельному TCP или UDP подключению</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/socksstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>SocksOptionsClass</name>
    <message>
        <source>Disable direct connections</source>
        <translation>Запретить прямые подключения</translation>
    </message>
    <message>
        <source>Port Forwarding</source>
        <translation>Перенаправление портов</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Stream Proxy</source>
        <translation>Прокси потока</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Вверх</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Connection Proxy</source>
        <translation>Прокси подключения</translation>
    </message>
    <message>
        <source>Use account connection proxy settings</source>
        <translation>Использовать настройки прокси из аккаунта</translation>
    </message>
    <message>
        <source>Listening port:</source>
        <translation>Прослушиваемый порт:</translation>
    </message>
    <message>
        <source>Use proxy on account server</source>
        <translation>Использовать прокси на сервере аккаунта</translation>
    </message>
    <message>
        <source>Outgoing Connections</source>
        <translation>Исходящие подключения</translation>
    </message>
    <message>
        <source>Connect timeout:</source>
        <translation>Таймаут подключения:</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <source>Incoming Connections</source>
        <translation>Входящие подключения</translation>
    </message>
</context>
<context>
    <name>SocksStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Поток удалён</translation>
    </message>
    <message>
        <source>Unsupported stream mode</source>
        <translation>Не поддерживаемый режим потока</translation>
    </message>
    <message>
        <source>Remote client cant connect to given hosts</source>
        <translation>Удалённый клиент не смог подключиться к полученным хостам</translation>
    </message>
    <message>
        <source>Failed to activate stream</source>
        <translation>Не удалось активировать поток</translation>
    </message>
    <message>
        <source>Failed to create hosts</source>
        <translation>Не удалось создать хост</translation>
    </message>
    <message>
        <source>Direct connection not established</source>
        <translation>Прямое подключение не установлено</translation>
    </message>
    <message>
        <source>Invalid host</source>
        <translation>Неверный хост</translation>
    </message>
    <message>
        <source>Cant connect to given hosts</source>
        <translation>Не удалось подключиться к полученным хостам</translation>
    </message>
    <message>
        <source>Failed to connect to host</source>
        <translation>Не удалось подключиться к хосту</translation>
    </message>
</context>
<context>
    <name>SocksStreams</name>
    <message>
        <source>SOCKS5 Data Stream</source>
        <translation>SOCKS5 поток данных</translation>
    </message>
    <message>
        <source>Allows to initiate SOCKS5 stream of data between two XMPP entities</source>
        <translation>Позволяет инициировать SOCKS5 поток данных между двумя XMPP сущностями</translation>
    </message>
    <message>
        <source>Supports the initiating of the SOCKS5 stream of data between two XMPP entities</source>
        <translation>Поддерживает инициализацию SOCKS5 потока данных между двумя XMPP сущностями</translation>
    </message>
    <message>
        <source>Data is transferred out-band over TCP or UDP connection</source>
        <translation>Данные передаются по отдельному TCP или UDP подключению</translation>
    </message>
</context>
</TS>
